Struct amazon_sp_fulfillment_outbound::models::fulfillment_shipment::FulfillmentShipment
source · [−]pub struct FulfillmentShipment {
pub amazon_shipment_id: String,
pub fulfillment_center_id: String,
pub fulfillment_shipment_status: FulfillmentShipmentStatus,
pub shipping_date: Option<String>,
pub estimated_arrival_date: Option<String>,
pub shipping_notes: Option<Vec<String>>,
pub fulfillment_shipment_item: Vec<FulfillmentShipmentItem>,
pub fulfillment_shipment_package: Option<Vec<FulfillmentShipmentPackage>>,
}Expand description
FulfillmentShipment : Delivery and item information for a shipment in a fulfillment order.
Fields
amazon_shipment_id: StringA shipment identifier assigned by Amazon.
fulfillment_center_id: StringAn identifier for the fulfillment center that the shipment will be sent from.
fulfillment_shipment_status: FulfillmentShipmentStatusThe current status of the shipment.
shipping_date: Option<String>estimated_arrival_date: Option<String>shipping_notes: Option<Vec<String>>Provides additional insight into shipment timeline. Primairly used to communicate that actual delivery dates aren’t available.
fulfillment_shipment_item: Vec<FulfillmentShipmentItem>An array of fulfillment shipment item information.
fulfillment_shipment_package: Option<Vec<FulfillmentShipmentPackage>>An array of fulfillment shipment package information.
Implementations
sourceimpl FulfillmentShipment
impl FulfillmentShipment
sourcepub fn new(
amazon_shipment_id: String,
fulfillment_center_id: String,
fulfillment_shipment_status: FulfillmentShipmentStatus,
fulfillment_shipment_item: Vec<FulfillmentShipmentItem>
) -> FulfillmentShipment
pub fn new(
amazon_shipment_id: String,
fulfillment_center_id: String,
fulfillment_shipment_status: FulfillmentShipmentStatus,
fulfillment_shipment_item: Vec<FulfillmentShipmentItem>
) -> FulfillmentShipment
Delivery and item information for a shipment in a fulfillment order.